@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ NoteLockAttributeTest::NoteLockAttributeTest(QObject *parent)
 {
 }
 
-NoteLockAttributeTest::~NoteLockAttributeTest()
-{
-}
+NoteLockAttributeTest::~NoteLockAttributeTest() = default;
 
 void NoteLockAttributeTest::shouldHaveType()
 {
