@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ ShowFolderNotesAttributeTest::ShowFolderNotesAttributeTest(QObject *parent)
 {
 }
 
-ShowFolderNotesAttributeTest::~ShowFolderNotesAttributeTest()
-{
-}
+ShowFolderNotesAttributeTest::~ShowFolderNotesAttributeTest() = default;
 
 void ShowFolderNotesAttributeTest::shouldHaveType()
 {
