@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,13 +13,11 @@
 #include <QTextEdit>
 
 using namespace NoteShared;
-NoteEditorUtils::NoteEditorUtils()
-{
-}
+NoteEditorUtils::NoteEditorUtils() = default;
 
 void NoteEditorUtils::addCheckmark(QTextCursor &cursor)
 {
-    static const QChar unicode[] = {0x2713};
+    static const QChar unicode[] = {QChar(0x2713)};
     const int size = sizeof(unicode) / sizeof(QChar);
     const int position = cursor.position();
     cursor.movePosition(QTextCursor::StartOfLine);
