@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,6 @@
 #include <Akonadi/ChangeRecorder>
 
 #include <KColorScheme>
-#include <KIconLoader>
 #include <KLocalizedString>
 
 #include <QFontDatabase>
@@ -28,9 +27,7 @@ KNotesAkonadiTray::KNotesAkonadiTray(QWidget *parent)
     updateNumberOfNotes(0);
 }
 
-KNotesAkonadiTray::~KNotesAkonadiTray()
-{
-}
+KNotesAkonadiTray::~KNotesAkonadiTray() = default;
 
 void KNotesAkonadiTray::slotGeneralPaletteChanged()
 {
@@ -41,7 +38,7 @@ void KNotesAkonadiTray::slotGeneralPaletteChanged()
 void KNotesAkonadiTray::updateNumberOfNotes(int number)
 {
     if (KNotesGlobalConfig::self()->systemTrayShowNotes() && number != 0) {
-        const int overlaySize = KIconLoader::SizeSmallMedium;
+        const int overlaySize = 22;
 
         const QString countString = QString::number(number);
         QFont countFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
