@@ -169,8 +169,8 @@ KNotesApp::KNotesApp(QWidget *parent)
     // get the most recent XML UI file
     QString xmlFileName(componentName() + QLatin1String("ui.rc"));
 #pragma message("port QT5")
-
-    QString filter(QLatin1String("kxmlgui5/knotes/") + xmlFileName); // QT5 = componentData().componentName() + QLatin1Char('/') + xmlFileName;
+    QString filter(QStringLiteral("kxmlgui" QT_STRINGIFY(QT_VERSION_MAJOR) "/knotes/")
+                   + xmlFileName); // QT5 = componentData().componentName() + QLatin1Char('/') + xmlFileName;
     const QStringList fileList = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, filter)
         + QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, xmlFileName); // QT5 =
 #pragma message("port QT5")
