@@ -10,8 +10,7 @@
 #include "knotes-version.h"
 #include "knotes_debug.h"
 #include "knotes_options.h"
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "notes/knotesmigrateapplication.h"
 #endif
 #include <KLocalizedString>
@@ -31,11 +30,13 @@ int main(int argc, char *argv[])
     // Disable session management
     qunsetenv("SESSION_MANAGER");
 
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     Application app(argc, &argv);
     KCrash::initialize();
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KNotesMigrateApplication migrate;
     migrate.migrate();
 #endif
@@ -45,7 +46,7 @@ int main(int argc, char *argv[])
                          QStringLiteral(KNOTES_VERSION),
                          i18n("KDE Notes"),
                          KAboutLicense::GPL,
-                         i18n("Copyright © 1997–2021 KNotes authors"));
+                         i18n("Copyright © 1997–%1 KNotes authors", QStringLiteral("2022")));
     knotesAuthors(aboutData);
     app.setAboutData(aboutData);
     QCommandLineParser *cmdArgs = app.cmdArgs();
