@@ -19,7 +19,7 @@
 #include "configdialog/knoteeditorconfigwidget.h"
 #include <KAuthorized>
 #include <KLocalizedString>
-#include <KNewStuff3/KNS3/QtQuickDialogWrapper>
+#include <KNS3/QtQuickDialogWrapper>
 
 #include <QCheckBox>
 #include <QLabel>
@@ -167,9 +167,14 @@ KNotePrintConfig::KNotePrintConfig(QWidget *parent, const QVariantList &args)
 
 void KNotePrintConfig::slotDownloadNewThemes()
 {
-    if (!KNS3::QtQuickDialogWrapper(QStringLiteral("kwinswitcher.knsrc")).exec().isEmpty()) {
-        mSelectTheme->loadThemes();
-    }
+    auto newStuffDialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("kwinswitcher.knsrc"));
+    connect(newStuffDialog, &KNS3::QtQuickDialogWrapper::closed, this, [newStuffDialog, this]() {
+        if (!newStuffDialog->changedEntries().isEmpty()) {
+            mSelectTheme->loadThemes();
+        }
+        newStuffDialog->deleteLater();
+    });
+    newStuffDialog->open();
 }
 
 void KNotePrintConfig::slotThemeChanged()
