@@ -20,6 +20,7 @@
 #include <KLocalizedString>
 #include <KToggleAction>
 
+#include <QActionGroup>
 #include <QColorDialog>
 #include <QIcon>
 #include <QMenu>
@@ -148,9 +149,7 @@ KNoteEdit::KNoteEdit(KActionCollection *actions, QWidget *parent)
     slotCursorPositionChanged();
 }
 
-KNoteEdit::~KNoteEdit()
-{
-}
+KNoteEdit::~KNoteEdit() = default;
 
 void KNoteEdit::setColor(const QColor &fg, const QColor &bg)
 {
