@@ -3,7 +3,7 @@
 
   SPDX-FileCopyrightText: 2002-2003 Daniel Molkentin <molkentin@kde.org>
   SPDX-FileCopyrightText: 2004-2006 Michael Brade <brade@kde.org>
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -43,7 +43,7 @@
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/ItemModifyJob>
-#include <akonadi/session.h>
+#include <Akonadi/Session>
 
 #include <KMime/KMimeMessage>
 
@@ -355,7 +355,7 @@ QString KNotesPart::name(Akonadi::Item::Id id) const
     if (note) {
         return note->text();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -366,7 +366,7 @@ QString KNotesPart::text(Akonadi::Item::Id id) const
     if (note) {
         return note->description();
     } else {
-        return QString();
+        return {};
     }
 }
 
