@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,14 +15,12 @@ KNoteGrantleePrint::KNoteGrantleePrint(const QString &themePath)
 {
 }
 
-KNoteGrantleePrint::~KNoteGrantleePrint()
-{
-}
+KNoteGrantleePrint::~KNoteGrantleePrint() = default;
 
 QString KNoteGrantleePrint::notesToHtml(const QList<KNotePrintObject *> &lst)
 {
     if (lst.isEmpty()) {
-        return QString();
+        return {};
     }
     QVariantList notes;
     notes.reserve(lst.count());
