@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ KNotePrintSelectThemeComboBox::KNotePrintSelectThemeComboBox(QWidget *parent)
     loadThemes();
 }
 
-KNotePrintSelectThemeComboBox::~KNotePrintSelectThemeComboBox()
-{
-}
+KNotePrintSelectThemeComboBox::~KNotePrintSelectThemeComboBox() = default;
 
 void KNotePrintSelectThemeComboBox::loadThemes()
 {
